@@ -45,22 +45,6 @@ test_adw_expander_row_subtitle (void)
 }
 
 
-static void
-test_adw_expander_row_icon_name (void)
-{
-  AdwExpanderRow *row = g_object_ref_sink (ADW_EXPANDER_ROW (adw_expander_row_new ()));
-
-  g_assert_nonnull (row);
-
-  g_assert_null (adw_expander_row_get_icon_name (row));
-
-  adw_expander_row_set_icon_name (row, "dummy-icon-name");
-  g_assert_cmpstr (adw_expander_row_get_icon_name (row), ==, "dummy-icon-name");
-
-  g_assert_finalize_object (row);
-}
-
-
 static void
 test_adw_expander_row_expanded (void)
 {
@@ -126,6 +110,47 @@ test_adw_expander_row_show_enable_switch (void)
   g_assert_finalize_object (row);
 }
 
+static void
+test_adw_expander_row_title_lines (void)
+{
+  AdwExpanderRow *row = g_object_ref_sink (ADW_EXPANDER_ROW (adw_expander_row_new ()));
+  g_assert_nonnull (row);
+
+  g_assert_cmpint (adw_expander_row_get_title_lines (row), ==, 0);
+
+  g_test_expect_message (ADW_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL, "adw_action_row_set_title_lines: assertion 'title_lines >= 0' failed");
+  adw_expander_row_set_title_lines (row, -1);
+  g_test_assert_expected_messages ();
+
+  g_assert_cmpint (adw_expander_row_get_title_lines (row), ==, 0);
+
+  adw_expander_row_set_title_lines (row, 1);
+  g_assert_cmpint (adw_expander_row_get_title_lines (row), ==, 1);
+
+  g_assert_finalize_object (row);
+}
+
+
+static void
+test_adw_expander_row_subtitle_lines (void)
+{
+  AdwExpanderRow *row = g_object_ref_sink (ADW_EXPANDER_ROW (adw_expander_row_new ()));
+  g_assert_nonnull (row);
+
+  g_assert_cmpint (adw_expander_row_get_subtitle_lines (row), ==, 0);
+
+  g_test_expect_message (ADW_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL, "adw_action_row_set_subtitle_lines: assertion 'subtitle_lines >= 0' failed");
+  adw_expander_row_set_subtitle_lines (row, -1);
+  g_test_assert_expected_messages ();
+
+  g_assert_cmpint (adw_expander_row_get_subtitle_lines (row), ==, 0);
+
+  adw_expander_row_set_subtitle_lines (row, 1);
+  g_assert_cmpint (adw_expander_row_get_subtitle_lines (row), ==, 1);
+
+  g_assert_finalize_object (row);
+}
+
 
 int
 main (int   argc,
@@ -136,10 +161,11 @@ main (int   argc,
 
   g_test_add_func("/Adwaita/ExpanderRow/add_remove", test_adw_expander_row_add_remove);
   g_test_add_func("/Adwaita/ExpanderRow/subtitle", test_adw_expander_row_subtitle);
-  g_test_add_func("/Adwaita/ExpanderRow/icon_name", test_adw_expander_row_icon_name);
   g_test_add_func("/Adwaita/ExpanderRow/expanded", test_adw_expander_row_expanded);
   g_test_add_func("/Adwaita/ExpanderRow/enable_expansion", test_adw_expander_row_enable_expansion);
   g_test_add_func("/Adwaita/ExpanderRow/show_enable_switch", test_adw_expander_row_show_enable_switch);
+  g_test_add_func("/Adwaita/ExpanderRow/title_lines", test_adw_expander_row_title_lines);
+  g_test_add_func("/Adwaita/ExpanderRow/subtitle_lines", test_adw_expander_row_subtitle_lines);
 
   return g_test_run();
 }
